Sbinsmth_nom: List vector containing numbers of options and boundaries.
Description
Set up objects needed for analyses of nominal data.
Usage
Sbinsmth_nom(bdry_nom, SfdList_nom)
Arguments
- bdry_nom
Vector of length two containing the initial and final
values of the scofre index.
- SfdList_nom
A list vector of length equal to number of items.
Each object is a list object containing the containing number of options
and the nominal parameter matrix estimated by the mirt package.